@@ -20,8 +20,10 @@
 #include <string.h>
 
 #include <audacious/i18n.h>
+#include <audacious/input.h>
 #include <audacious/misc.h>
 #include <audacious/plugin.h>
+#include <libaudcore/audstrings.h>
 
 #define MIN_BPM         1
 #define MAX_BPM         512
@@ -71,8 +73,6 @@ double tact_form[TACT_ID_MAX][TACT_FORM_MAX] = {
     {1.0, 0.5, 0.5, 0.6, 0.5, 0.5, 0.0, 0.0}
 };
 
-static bool_t stop_flag = FALSE;
-
 static bool_t metronom_is_our_fd(const char * filename, VFSFile *fd)
 {
     if (!strncmp(filename, "tact://", 7))
@@ -131,8 +131,7 @@ static bool_t metronom_get_cp(const char *filename, metronom_t *pmetronom, char
     return TRUE;
 }
 
-static bool_t metronom_play(InputPlayback *playback, const char *filename,
-    VFSFile *file, int start_time, int stop_time, bool_t pause)
+static bool_t metronom_play (const char * filename, VFSFile * file)
 {
     metronom_t pmetronom;
     int16_t data[BUF_SAMPLES];
@@ -142,24 +141,17 @@ static bool_t metronom_play(InputPlayback *playback, const char *filename,
     int datacurrent = datamiddle;
     int datalast = datamiddle;
     int data_form[TACT_FORM_MAX];
-    bool_t error = FALSE;
 
-    if (playback->output->open_audio(FMT_S16_NE, AUDIO_FREQ, 1) == 0)
-    {
-        error = TRUE;
-        goto error_exit;
-    }
+    if (aud_input_open_audio(FMT_S16_NE, AUDIO_FREQ, 1) == 0)
+        return FALSE;
 
     if (!metronom_get_cp(filename, &pmetronom, NULL))
     {
         fprintf (stderr, "Invalid metronom tact parameters in URI %s", filename);
-        goto error_exit;
+        return FALSE;
     }
 
-    if (pause)
-        playback->output->pause(TRUE);
-
-    playback->set_params(playback, sizeof(data[0]) * 8 * AUDIO_FREQ, AUDIO_FREQ, 1);
+    aud_input_set_bitrate(sizeof(data[0]) * 8 * AUDIO_FREQ);
 
     tact = 60 * AUDIO_FREQ / pmetronom.bpm;
 
@@ -169,11 +161,8 @@ static bool_t metronom_play(InputPlayback *playback, const char *filename,
         data_form[num] = MAX_AMPL * tact_form[pmetronom.id][num];
     }
 
-    stop_flag = FALSE;
-    playback->set_pb_ready(playback);
-
     num = 0;
-    while (!stop_flag)
+    while (!aud_input_check_stop())
     {
         int i;
 
@@ -205,27 +194,10 @@ static bool_t metronom_play(InputPlayback *playback, const char *filename,
             t++;
         }
 
-        if (!stop_flag)
-            playback->output->write_audio(data, BUF_BYTES);
+        aud_input_write_audio(data, BUF_BYTES);
     }
 
-error_exit:
-
-    stop_flag = TRUE;
-
-    return !error;
-}
-
-static void metronom_stop(InputPlayback * playback)
-{
-    stop_flag = TRUE;
-    playback->output->abort_write();
-}
-
-static void metronom_pause(InputPlayback * playback, bool_t pause)
-{
-    if (!stop_flag)
-        playback->output->pause(pause);
+    return TRUE;
 }
 
 static Tuple *metronom_probe_for_tuple(const char * filename, VFSFile *fd)
@@ -235,7 +207,7 @@ static Tuple *metronom_probe_for_tuple(const char * filename, VFSFile *fd)
     char *tmp = NULL;
 
     if (metronom_get_cp(filename, &metronom, &tmp))
-        tuple_set_str(tuple, FIELD_TITLE, NULL, tmp);
+        tuple_set_str(tuple, FIELD_TITLE, tmp);
 
     str_unref(tmp);
 
@@ -258,7 +230,5 @@ AUD_INPUT_PLUGIN
     .schemes = schemes,
     .is_our_file_from_vfs = metronom_is_our_fd,
     .play = metronom_play,
-    .stop = metronom_stop,
-    .pause = metronom_pause,
     .probe_for_tuple = metronom_probe_for_tuple,
 )
