@@ -11,11 +11,7 @@ extern "C" {
 
 void InitSettings (const ModplugSettings * settings);
 int CanPlayFileFromVFS (const char * filename, VFSFile * file);
-bool_t PlayFile (InputPlayback * data, const char * filename, VFSFile * file,
- int start_time, int stop_time, bool_t pause);
-void Stop (InputPlayback * data);
-void Pause (InputPlayback * data, bool_t pause);
-void mseek (InputPlayback * data, int time);
+bool_t PlayFile (const char * filename, VFSFile * file);
 Tuple * GetSongTuple (const char * filename, VFSFile * file);
 
 #ifdef __cplusplus
