@@ -614,6 +614,10 @@ static gboolean skin_load (Skin * skin, const gchar * path)
         ui_skinned_playstatus_set_size (mainwin_playstatus, 11,
          cairo_image_surface_get_height (skin->pixmaps[SKIN_PLAYPAUSE]));
 
+    // hide the equalizer graph if we have a short eqmain.bmp
+    gtk_widget_set_visible (equalizerwin_graph,
+     cairo_image_surface_get_height (skin->pixmaps[SKIN_EQMAIN]) >= 315);
+
     return TRUE;
 }
 
